@@ -25,7 +25,7 @@ sub permute(&@)
  {my $s = shift;       # Subroutine to call to process each permutation
 
   my $n = scalar(@_);  # Size of array to be permuted
-  return 0 unless $n;  # Empty lists cannot be permuted
+# return 0 unless $n;  # Empty lists cannot be permuted - removed per Philipp Rumpf
   my $l = 0;           # Item being permuted           
   my @p = ();          # Current permutations
   my @P = @_;          # Array to permute   
@@ -63,7 +63,7 @@ use vars qw(@ISA @EXPORT $VERSION);
 
 @ISA     = qw(Exporter);
 @EXPORT  = qw(permute);
-$VERSION = '1.004'; # Saturday 21 March 2009
+$VERSION = '1.005';
 
 =head1 Description
 
@@ -101,9 +101,9 @@ the "./" notation, you can do this:
 
 =head1 Author
 
-PhilipRBrenan@handybackup.com
+PhilipRBrenan@appaapps.com
 
-http://www.handybackup.com
+http://www.appaapps.com
 
 =head1 See Also
 
